[![Build Status](https://travis-ci.org/navio-online/navio-gitlab.png?branch=master)](https://travis-ci.org/navio-online/navio-gitlab)

Travis CI helper libs
=====================

## Features

* Common use cases covered under single methods
* Keeps build files clean and powerfull

## Installation


You can install navio-builder from the Python Package Index (PyPI) or from source.

Using pip

```bash
$ pip install navio-gitlab
```

Using easy_install

```bash
$ easy_install navio-gitlab
```

## Example


TODO


## Contributors/Contributing


If you want to make changes the repo is at https://github.com/navio-online/navio-gitlab. You will need [pytest](http://www.pytest.org) to run the tests and [navio-builder](https://github.com/navio-online/navio-builder) tool to build modules

```bash
$ nb test
```

It will be great if you can raise a [pull request](https://help.github.com/articles/using-pull-requests) once you are done.

If you find any bugs or need new features please raise a ticket in the [issues section](https://github.com/navio-online/navio-gitlab/issues) of the github repo.
    
## License

navio-travis is licensed under a [Apache 2.0 license](http://www.apache.org/licenses/LICENSE-2.0)
